Function git_version::set_env[][src]

pub fn set_env()

Instruct cargo to set the VERSION environment variable to the version as indicated by git describe --always --dirty=-modified.

Also instructs cargo to always re-run the build script and recompile the code, to make sure the version number is always correct.